"""
Recruitin Boolean Search - Data Models Package

This package contains all data models and taxonomies used for boolean search generation.
"""

from .functiegroep import FunctieGroep
from .taxonomie import FUNCTIEGROEPEN

__all__ = ["FunctieGroep", "FUNCTIEGROEPEN"]
